@@ -2,6 +2,9 @@ from pydantic import BaseModel
 from typing import Optional, List
 from enum import IntEnum
 
+class OrganicProductionTypeEnum(IntEnum):
+    CONVENTIONAL = 0
+    ORGANIC = 1
 class AgriculturalProduction(BaseModel):
     id: Optional[int] = None
     farmId: int
@@ -12,7 +15,7 @@ class AgriculturalProduction(BaseModel):
     cropProduction: float
     irrigatedArea: float
     cultivatedArea: float
-    organicProductionType: int
+    organicProductionType: OrganicProductionTypeEnum
     variableCosts: float
     landValue: float
     sellingPrice: float
@@ -27,7 +30,7 @@ class AgriculturalProductionDTO(BaseModel):
     cropProduction: float
     irrigatedArea: float
     cultivatedArea: float
-    organicProductionType: int
+    organicProductionType: OrganicProductionTypeEnum
     variableCosts: float
     landValue: float
     sellingPrice: float
@@ -187,6 +190,8 @@ class ValueFromSPDTO(BaseModel):
     farmGrossIncome: float
     agriculturalLand: float
     crops: dict[str,CropDataDTO]
+    totalVariableCosts: float
+    rentBalanceArea: float
 
 class LivestockDTO(BaseModel):
     numberOfAnimals: float
@@ -261,4 +266,6 @@ class AgroManagementDecisionFromLP(BaseModel):
 class DataToLPDTO(BaseModel):
     values: List[ValueToLPDTO]
     agriculturalProductions: List[AgriculturalProductionDTO]
+    ignoreLP: Optional[bool]
+    ignoreLMM: Optional[bool]
 
