@@ -6,6 +6,8 @@ class SimulationScenario(BaseModel):
     id: Optional[int] = None
     populationId: int
     yearId: int
+    ignoreLP: Optional[bool]
+    ignoreLMM: Optional[bool]
     shortTermModelBranch: str
     longTermModelBranch: str
     horizon: int
